@@ -4,20 +4,23 @@ import numpy as np
 import pandas as pd
 from datetime import datetime
 import pandas as pd
-import pathlib
 from datetime import timedelta
 import random
-
+import os
 
 # load min_val and max_val to normalize data & load latent dimension
-LOC_VARS = "/important_variables/"
-NAME_MAX_VAL = "max_val.npy"
-NAME_MIN_VAL = "min_val.npy"
-ENCODER_LOCATION = "encoder"
+script_dir = os.path.dirname(__file__)
+rel_path_min_val = "important_variables/min_val.npy"
+rel_path_max_val = "important_variables/max_val.npy"
+rel_path_latent_dim = "important_variables/latent_dim.txt"
 
-min_val = np.load(LOC_VARS + NAME_MIN_VAL)
-max_val = np.load(LOC_VARS + NAME_MAX_VAL)
-LATENT_DIM = int(open(LOC_VARS + "/latent_dim.txt", "r").read())
+abs_path_min_val = os.path.join(script_dir, rel_path_min_val)
+abs_path_max_val = os.path.join(script_dir, rel_path_max_val)
+abs_path_latent_val = os.path.join(script_dir, rel_path_latent_dim)
+
+min_val = np.load(abs_path_min_val)
+max_val = np.load(abs_path_max_val)
+LATENT_DIM = int(open(abs_path_latent_val, "r").read())
 
 
 ## Normalize data
